import os
import datetime
import platform

__all__ = ['runtimestamp']

def runtimestamp(user=None):
    '''
    Returns Runtime Metadata for Jupyter Notebooks
    '''
    if not user:
        user = os.environ.get("USER")
    today = datetime.datetime.now()
    version = platform.python_version()
    os_platform = platform.platform()
    
    print(
        "Updated {today}\nBy {user}\nUsing Python {version}\nOn {os_platform}".format(
            today = today,
            user = user,
            version = version,
            os_platform = os_platform
        )
    )



import sys
from setuptools import setup

setup(name='runtimestamp',
	packages=['runtimestamp'],
	version='0.0.3',
	description='Leaves an timestamp and signature at the top of every notebook',
	author='leon yin',
	author_email='',
	url='https://github.com/yinleon/runtimestamp',
	keywords='jupyter notebook, timestamp',
	license='MIT',
	install_requires=[]
)
